==> EnToFa-1.4.tar.gz: EnToFa-1.4/README.md <==
<br>

<h1 align="center">
  Potplayer English To Persian Translator
</h1>

<p align="center"><img src="/assets/images/07.png" alt="E2F" /></p>

- [What is EnToFa?](#what-is-bura-cli)
- [Installation Windows](#installation-windows)
- [Potplayer Settings](#potplayer-settings)

## What is EnToFa?

In the normal mode, **Potplayer** can simultaneously translate all the subtitles and, for individual words, if you click on the word, it will open the word's translation in your browser, which may take a considerable amount of time. However, with **EnToFa**, which is a Python code, it translates words from English to Persian instantly. This version is only available for Windows.

## Installation Windows

After installing `Python` and `pip`, you only need to install `EnToFa` by running the following command:

```bash
pip install EnToFa
```

That's it!

## Potplayer Settings

<details>
	<summary>Step 1</summary>
	<br/>
	<div>Right-click on an English word and then click on "Customize."</div>
	<br/>
	<img src="/assets/images/01.png" alt="01 png" />
</details>

<details>
	<summary>Step 2</summary>
	<br/>
	<div>Click on "Add".</div>
	<br/>
	<img src="/assets/images/02.png" alt="02 png" />
</details>

<details>
	<summary>Step 3</summary>
	<br/>
	<div>Please provide the following information in the title and path:</div>
	<div>Title: Translator</div>
	<div>Path: EnToFa "%%SS"</div>
	<br/>
	<img src="/assets/images/03.png" alt="03 png" />
</details>

<details>
	<summary>Step 4</summary>
	<br/>
	<div>Click on "Ok".</div>
	<br/>
	<img src="/assets/images/04.png" alt="04 png" />
</details>

<details>
	<summary>Step 5</summary>
	<br/>
	<div>Click on the newly entered information and use the "Up" button to move it to the top.</div>
	<br/>
	<img src="/assets/images/05.png" alt="05 png" />
</details>

<details>
	<summary>Step 6</summary>
	<br/>
	<div>As you can see, our information is being recorded.</div>
	<br/>
	<img src="/assets/images/06.png" alt="06 png" />
</details>

<details>
	<summary>Step 7</summary>
	<br/>
	<div>By clicking on each word, a translation of that word into Persian will appear as a notification.</div>
	<br/>
	<img src="/assets/images/07.png" alt="07 png" />
</details>

## License

This project is licensed under the [MIT License](LICENSE).

==> EnToFa-1.4.1.tar.gz: EnToFa-1.4.1/README.md <==
<br>

<h1 align="center">
  Potplayer English To Persian Translator
</h1>

<p align="center"><img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/07.png" alt="E2F" /></p>

- [What is EnToFa?](#what-is-bura-cli)
- [Installation Windows](#installation-windows)
- [Potplayer Settings](#potplayer-settings)

## What is EnToFa?

In the normal mode, **Potplayer** can simultaneously translate all the subtitles and, for individual words, if you click on the word, it will open the word's translation in your browser, which may take a considerable amount of time. However, with **EnToFa**, which is a Python code, it translates words from English to Persian instantly. This version is only available for Windows.

## Installation Windows

After installing `Python` and `pip`, you only need to install `EnToFa` by running the following command:

```bash
pip install EnToFa
```

That's it!

## Potplayer Settings

<details>
	<summary>Step 1</summary>
	<br/>
	<div>Right-click on an English word and then click on "Customize."</div>
	<br/>
	<img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/01.png" alt="01 png" />
</details>

<details>
	<summary>Step 2</summary>
	<br/>
	<div>Click on "Add".</div>
	<br/>
	<img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/02.png" alt="02 png" />
</details>

<details>
	<summary>Step 3</summary>
	<br/>
	<div>Please provide the following information in the title and path:</div>
	<div>Title: Translator</div>
	<div>Path: EnToFa "%%SS"</div>
	<br/>
	<img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/03.png" alt="03 png" />
</details>

<details>
	<summary>Step 4</summary>
	<br/>
	<div>Click on "Ok".</div>
	<br/>
	<img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/04.png" alt="04 png" />
</details>

<details>
	<summary>Step 5</summary>
	<br/>
	<div>Click on the newly entered information and use the "Up" button to move it to the top.</div>
	<br/>
	<img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/05.png" alt="05 png" />
</details>

<details>
	<summary>Step 6</summary>
	<br/>
	<div>As you can see, our information is being recorded.</div>
	<br/>
	<img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/06.png" alt="06 png" />
</details>

<details>
	<summary>Step 7</summary>
	<br/>
	<div>By clicking on each word, a translation of that word into Persian will appear as a notification.</div>
	<br/>
	<img src="https://raw.githubusercontent.com/jepbura/potplayer-english-to-persian-translator/master/assets/images/07.png" alt="07 png" />
</details>

## License

This project is licensed under the [MIT License](LICENSE).
